"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const parse_extended_header_1 = __importDefault(require("./parse-extended-header"));
const parse_chunks_1 = __importDefault(require("./parse-chunks"));
const parse_change_markers_1 = __importDefault(require("./parse-change-markers"));
function parseFileChanges(ctx) {
    const changedFiles = [];
    while (!ctx.isEof()) {
        const changed = parseFileChange(ctx);
        if (!changed) {
            break;
        }
        changedFiles.push(changed);
    }
    return changedFiles;
}
exports.default = parseFileChanges;
function parseFileChange(ctx) {
    if (!isComparisonInputLine(ctx.getCurLine())) {
        return;
    }
    ctx.nextLine();
    let isDeleted = false;
    while (!ctx.isEof()) {
        const extHeader = (0, parse_extended_header_1.default)(ctx);
        if (!extHeader) {
            break;
        }
        if (extHeader === 'deleted')
            isDeleted = true;
    }
    const changeMarkers = (0, parse_change_markers_1.default)(ctx);
    if (!changeMarkers) {
        return;
    }
    const chunks = (0, parse_chunks_1.default)(ctx);
    if (isDeleted) {
        return {
            type: 'DeletedFile',
            chunks,
            path: changeMarkers.deleted,
        };
    }
    else {
        return {
            type: 'ChangedFile',
            chunks,
            path: changeMarkers.added,
        };
    }
    return;
}
function isComparisonInputLine(line) {
    return line.indexOf('diff --git') === 0;
}
